==> sawmill6.4b3_crypt_src.tar.gz: sawmill-6.4b3/S77ffa16229d2f4825cd396c6d7b160de.h <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// then compilation!



















































 
#include "S749d2b576e15d77f0d14f186077e9ace.h"
 class S52b2679e781be36a71722155fcceae42; class Se812b5a98988bad1d5b8df118cb6cc7f; bool S246f208f356eaf067b7d9b9cc6911f40(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179); void S67eb11066480de14118716aae8441b64(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, const S749d2b576e15d77f0d14f186077e9ace &S44a8fc83e06c5a0a2bd68c1e2a5193cf, 
long Seaae26a6fb20ed3ef54fb23bfa0b1fcc, long Sb435e227d5dd201e1768b2bcb2e0aa81, bool S37b51d194a7513e45b56f6524f2d51f2); 
S749d2b576e15d77f0d14f186077e9ace Se1793d4340ddea6da606dff9ce62cb8a(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, const S749d2b576e15d77f0d14f186077e9ace &S44a8fc83e06c5a0a2bd68c1e2a5193cf, 
long Seaae26a6fb20ed3ef54fb23bfa0b1fcc, long Sb435e227d5dd201e1768b2bcb2e0aa81, bool S37b51d194a7513e45b56f6524f2d51f2); 
void S50b6f4810bfd1d61c11e1e3f76565269(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179); 
void Sf75f4aa85a694caa70ff9129085a038b(void); void Sdf248d188bbb95d2bc6946d8f241fc08(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, long S4e55e7722896a4b2d70f2124ff309db3, bool S347cb463fdcb62fdb912856d42fdfd6a, 
bool S1b5652b69de84af27321db9204ae1f93); void S14960036ea8977d9a1abf6f261137881(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, unsigned long S518d8a07ccee87913f52371001846423); void S554fcfd32d1bf69380a841e8a08a7e90(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179); void S7718077f81a79157f9b807802f0d068e(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179); S749d2b576e15d77f0d14f186077e9ace Sd5ce80687cdd99205bd8d27aa8d95a89(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, long S198a6617dc07f3411d5c2ab23837bf26, const S749d2b576e15d77f0d14f186077e9ace 
&Sd304ba20e96d87411588eeabac850e34); void S4c82a63201f40dc73a11e4918524f74b(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, int Sa3b4963694fc00c4b74b5f15b5107d01, S52b2679e781be36a71722155fcceae42 
&Se0e769a553a3eb724be27d6a3837c99c); void Se294ff47387fa95a404d4d7ba3b7a706(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, const S749d2b576e15d77f0d14f186077e9ace &Sbe05d559ccc3262d3e7d034ed3c56980, 
unsigned char *S8d777f385d3dfec8815d20f7496026dc); void Sfc2a3785e44a00c091984b74c640f412(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, const char *S467369f7c540795639eb51e6a1bf65f2); void Sc8113148be30f24d47f059e501eabfe9(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, long S10441c7d0c4dd18ccef1fe094292d263);

==> sawmill6.5b3_crypt_src.tar.gz: sawmill-6.5b3/S77ffa16229d2f4825cd396c6d7b160de.h <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// than compilation!



















































 
#include "S749d2b576e15d77f0d14f186077e9ace.h"
 class S52b2679e781be36a71722155fcceae42; class Se812b5a98988bad1d5b8df118cb6cc7f; typedef struct { 
char *S435ed7e9f07f740abf511a62c00eef6e; unsigned char *S8d777f385d3dfec8815d20f7496026dc; unsigned 
long Seaae26a6fb20ed3ef54fb23bfa0b1fcc; unsigned long Sb435e227d5dd201e1768b2bcb2e0aa81; } Scb03b623fb290a05663eebb4bdbe7595; 
extern Scb03b623fb290a05663eebb4bdbe7595 S72eec8cbf14d18844486da2338e22ba6[]; bool S246f208f356eaf067b7d9b9cc6911f40(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179); void S67eb11066480de14118716aae8441b64(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, const S749d2b576e15d77f0d14f186077e9ace &S44a8fc83e06c5a0a2bd68c1e2a5193cf, 
long Seaae26a6fb20ed3ef54fb23bfa0b1fcc, long Sb435e227d5dd201e1768b2bcb2e0aa81, bool S37b51d194a7513e45b56f6524f2d51f2); 
S749d2b576e15d77f0d14f186077e9ace Se1793d4340ddea6da606dff9ce62cb8a(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, const S749d2b576e15d77f0d14f186077e9ace &S44a8fc83e06c5a0a2bd68c1e2a5193cf, 
long Seaae26a6fb20ed3ef54fb23bfa0b1fcc, long Sb435e227d5dd201e1768b2bcb2e0aa81, bool S37b51d194a7513e45b56f6524f2d51f2); 
void S50b6f4810bfd1d61c11e1e3f76565269(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179); 
void Sf75f4aa85a694caa70ff9129085a038b(void); void Sdf248d188bbb95d2bc6946d8f241fc08(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, long S4e55e7722896a4b2d70f2124ff309db3, bool S347cb463fdcb62fdb912856d42fdfd6a, 
bool S1b5652b69de84af27321db9204ae1f93); void S14960036ea8977d9a1abf6f261137881(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, unsigned long S518d8a07ccee87913f52371001846423); void S554fcfd32d1bf69380a841e8a08a7e90(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179); void S7718077f81a79157f9b807802f0d068e(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179); S749d2b576e15d77f0d14f186077e9ace Sd5ce80687cdd99205bd8d27aa8d95a89(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, long S198a6617dc07f3411d5c2ab23837bf26, const S749d2b576e15d77f0d14f186077e9ace 
&Sd304ba20e96d87411588eeabac850e34); void S4c82a63201f40dc73a11e4918524f74b(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, int Sa3b4963694fc00c4b74b5f15b5107d01, S52b2679e781be36a71722155fcceae42 
&Se0e769a553a3eb724be27d6a3837c99c); void Se294ff47387fa95a404d4d7ba3b7a706(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, const S749d2b576e15d77f0d14f186077e9ace &Sbe05d559ccc3262d3e7d034ed3c56980, 
unsigned char *S8d777f385d3dfec8815d20f7496026dc); void Sfc2a3785e44a00c091984b74c640f412(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, const char *S467369f7c540795639eb51e6a1bf65f2, unsigned long &Seaae26a6fb20ed3ef54fb23bfa0b1fcc, 
unsigned long &Sb435e227d5dd201e1768b2bcb2e0aa81); void Sc8113148be30f24d47f059e501eabfe9(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, long S10441c7d0c4dd18ccef1fe094292d263);
